@@ -4,15 +4,22 @@ import hashlib
 BLOCKSIZE = 2 ** 10 * 128  # kb
 
 
-def hashfile(path):
-    md5 = hashlib.md5()
+def hashfile(path, hash_algo=None):
+
+    if not hash_algo or hash_algo == "md5":
+        h = hashlib.md5()
+    elif hash_algo == "sha512":
+        h = hashlib.sha512()
+    else:
+        raise Exception(f"{hash_algo} is unknown.")
+
     with open(path, "rb") as f:
         while True:
             buf = f.read(BLOCKSIZE)
             if len(buf) <= 0:
                 break
-            md5.update(buf)
-    return md5.hexdigest()
+            h.update(buf)
+    return h.hexdigest()
 
 
 def hashtext(text):
