@@ -4,11 +4,11 @@ import time
 import argparse
 import queue
 import threading
-from chkbit import IndexThread, Stat
+from chkbit import Context, IndexThread, Stat
 
 STATUS_CODES = """
 Status codes:
-  ROT: error, bitrot detected
+  DMG: error, data damage detected
   EIX: error, index damaged
   old: warning, file replaced by an older version
   new: new file
@@ -22,7 +22,7 @@ Status codes:
 class Main:
     def __init__(self):
         self.stdscr = None
-        self.bitrot_list = []
+        self.dmg_list = []
         self.err_list = []
         self.modified = False
         self.verbose = False
@@ -34,8 +34,8 @@ class Main:
         if stat == Stat.FLAG_MOD:
             self.modified = True
         else:
-            if stat == Stat.ERR_BITROT:
-                self.bitrot_list.append(path)
+            if stat == Stat.ERR_DMG:
+                self.dmg_list.append(path)
             elif stat == Stat.INTERNALEXCEPTION:
                 self.err_list.append(path)
             elif stat in [Stat.OK, Stat.UPDATE, Stat.NEW]:
@@ -47,11 +47,14 @@ class Main:
 
     def _parse_args(self):
         parser = argparse.ArgumentParser(
-            description="Checks files for bitrot. See https://github.com/laktak/chkbit-py",
+            description="Checks the data integrity of your files. See https://github.com/laktak/chkbit-py",
             epilog=STATUS_CODES,
             formatter_class=argparse.RawDescriptionHelpFormatter,
         )
-        parser.add_argument("PATH", nargs="+")
+
+        parser.add_argument(
+            "paths", metavar="PATH", type=str, nargs="*", help="directories to check"
+        )
 
         parser.add_argument(
             "-u",
@@ -60,13 +63,33 @@ class Main:
             help="update indices (without this chkbit will only verify files)",
         )
 
+        parser.add_argument(
+            "--algo",
+            type=str,
+            default="md5",
+            help="hash algorithm: md5, sha512",
+        )
+
         parser.add_argument(
             "-f", "--force", action="store_true", help="force update of damaged items"
         )
 
-        # parser.add_argument(
-        #     "-d", "--delete", action="store_true", help="remove all .chkbit files from target"
-        # )
+        parser.add_argument(
+            "-i",
+            "--verify-index",
+            action="store_true",
+            help="verify files in the index only (will not report new files)",
+        )
+
+        parser.add_argument(
+            "-w",
+            "--workers",
+            metavar="N",
+            action="store",
+            type=int,
+            default=5,
+            help="number of workers to use, default=5",
+        )
 
         parser.add_argument(
             "-q",
@@ -74,6 +97,7 @@ class Main:
             action="store_true",
             help="quiet, don't show progress/information",
         )
+
         parser.add_argument(
             "-v", "--verbose", action="store_true", help="verbose output"
         )
@@ -81,6 +105,8 @@ class Main:
         self.args = parser.parse_args()
         self.verbose = self.args.verbose
         self.quiet = self.args.quiet
+        if not self.args.paths:
+            parser.print_help()
 
     def _res_worker(self):
         while True:
@@ -93,15 +119,29 @@ class Main:
     def process(self):
 
         self.res_queue = queue.Queue()
+
+        # the todo queue is used to distribute the work
+        # to the index threads
         todo_queue = queue.Queue()
 
-        for path in self.args.PATH:
+        # put the initial paths into the queue
+        for path in self.args.paths:
             todo_queue.put(path)
 
+        context = Context(
+            self.args.verify_index,
+            self.args.update,
+            self.args.force,
+            self.args.algo,
+        )
+
+        # start indexing
         workers = [
-            IndexThread(idx, self.args, self.res_queue, todo_queue) for idx in range(5)
+            IndexThread(idx, context, self.res_queue, todo_queue)
+            for idx in range(self.args.workers)
         ]
 
+        # log the results from the workers
         res_worker = threading.Thread(target=self._res_worker)
         res_worker.daemon = True
         res_worker.start()
@@ -117,12 +157,12 @@ class Main:
             if self.modified:
                 print("Indices were updated.")
 
-        if self.bitrot_list:
-            print("chkbit detected bitrot in these files:", file=sys.stderr)
-            for err in self.bitrot_list:
+        if self.dmg_list:
+            print("chkbit detected damage in these files:", file=sys.stderr)
+            for err in self.dmg_list:
                 print(err, file=sys.stderr)
             print(
-                f"error: detected {len(self.bitrot_list)} file(s) with bitrot!",
+                f"error: detected {len(self.dmg_list)} file(s) with damage!",
                 file=sys.stderr,
             )
         if self.err_list:
@@ -130,15 +170,16 @@ class Main:
             for err in self.err_list:
                 print(err, file=sys.stderr)
 
-        if self.bitrot_list or self.err_list:
+        if self.dmg_list or self.err_list:
             sys.exit(1)
 
 
 def main():
     try:
         m = Main()
-        m.process()
-        m.print_result()
+        if m.args.paths:
+            m.process()
+            m.print_result()
     except KeyboardInterrupt:
         print("abort")
         sys.exit(1)
